@@ -119,7 +119,7 @@ public class ThrowExpression extends Expression
         boolean duplicates = false;
 
         for (Constructor constructor : constructors) {
-            if (constructor.getParameterTypes().length == arity) {
+            if (constructor.getParameterCount() == arity) {
                 candidates.add(constructor);
             }
         }
